**This is a fork of the original, stale project to fix some of the issues, add CI verification, and push to PyPI.**

[![Build Status](https://travis-ci.com/dsoprea/blockhash-python.svg?branch=master)](https://travis-ci.com/dsoprea/blockhash-python)
[![Coverage Status](https://coveralls.io/repos/github/dsoprea/blockhash-python/badge.svg?branch=master)](https://coveralls.io/github/dsoprea/blockhash-python?branch=master)

blockhash-python
================

This is a perceptual image hash calculation tool based on algorithm descibed in
Block Mean Value Based Image Perceptual Hashing by Bian Yang, Fan Gu and Xiamu Niu.

Installation
------------

Either download/clone the project directly, or install the "phash-blockhashio" package from PyPI.


Usage
-----

This script requires Python 2.x or Python 3 and Python Imaging (PIL) 1.1.6 or above.

Run `blockhash [list of images]` for calculating hashes.

Run `blockhash --help` for the list of options.

License
-------

Copyright 2014 Commons Machinery http://commonsmachinery.se/

Distributed under an MIT license, please see LICENSE in the top dir.

Contact: dev@commonsmachinery.se
